==> mediawiki-1.21.1.tar.gz: mediawiki-1.21.1/extensions/LocalisationUpdate/LocalisationUpdate.i18n.php <==
<?php
/**
 * Internationalisation file for LocalisationUpdate extension.
 *
 * @file
 * @ingroup Extensions
 */
 
$messages = array();

/** English
 * @author Tom Maaswinkel
 */
$messages['en'] = array(
	'localisationupdate-desc' => 'Keeps the localised messages as up to date as possible',
);

/** Message documentation (Message documentation)
 * @author Fryed-peach
 * @author Purodha
 * @author Shirayuki
 */
$messages['qqq'] = array(
	'localisationupdate-desc' => '{{desc|name=Localisation Update|url=http://www.mediawiki.org/wiki/Extension:LocalisationUpdate}}',
);

/** Afrikaans (Afrikaans)
 * @author Naudefj
 */
$messages['af'] = array(
	'localisationupdate-desc' => 'Hou die gelokaliseerde boodskappe so op datum as moontlik',
);

/** Arabic (العربية)
 * @author Meno25
 */
$messages['ar'] = array(
	'localisationupdate-desc' => 'يبقي الرسائل المترجمة محدثة كأفضل ما يكون',
);

/** Asturian (asturianu)
 * @author Xuacu
 */
$messages['ast'] = array(
	'localisationupdate-desc' => 'Caltién los mensaxes llocalizaos tan anovaos como se pueda',
);

/** Bashkir (башҡортса)
 * @author Assele
 */
$messages['ba'] = array(
	'localisationupdate-desc' => 'Локалләштерелгән хәбәрҙәрҙең мөмкин тиклем яңы булыуын тәьмин итә',
);

/** Bavarian (Boarisch)
 * @author Man77
 */
$messages['bar'] = array(
	'localisationupdate-desc' => "Lokalisiade Texte und Nåchrichtn so aktuell håidn wia's gråd gehd",
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎)
 * @author EugeneZelenko
 * @author Wizardist
 */
$messages['be-tarask'] = array(
	'localisationupdate-desc' => 'Сочыць за актуальнасьцю лякалізаваных паведамленьняў, наколькі гэта магчыма',
);

/** Bulgarian (български)
 * @author DCLXVI
 */
$messages['bg'] = array(
	'localisationupdate-desc' => 'Поддържа локализираните съобщения възможно най-актуални',
);

/** Bengali (বাংলা)
 * @author Bellayet
 */
$messages['bn'] = array(
	'localisationupdate-desc' => 'স্থানীয়করণকৃত বার্তাসমূহ যথাসম্ভব হালনাগাদ রাখে',
);

/** Breton (brezhoneg)
 * @author Fulup
 */
$messages['br'] = array(
	'localisationupdate-desc' => "Derc'hel da hizivaat ar c'hemennoù troet ken fonnus ha ma'z eus tu",
);

/** Bosnian (bosanski)
 * @author CERminator
 */
$messages['bs'] = array(
	'localisationupdate-desc' => 'Zadržavanje lokaliziranih poruka ažurnim koliko je god moguće',
);

/** Catalan (català)
 * @author Paucabot
 */
$messages['ca'] = array(
	'localisationupdate-desc' => 'Manté els missatges localitzats tan actualitzats com sigui possible',
);

/** Czech (česky)
 * @author Mormegil
 */
$messages['cs'] = array(
	'localisationupdate-desc' => 'Udržuje lokalizovaná hlášení co možná nejaktuálnější',
);

/** Welsh (Cymraeg)
 * @author Lloffiwr
 */
$messages['cy'] = array(
	'localisationupdate-desc' => "Yn diweddaru'r cyfieithiadau o negeseuon mor aml â phosib",
);

/** Danish (dansk)
 * @author Peter Alberti
 */
$messages['da'] = array(
	'localisationupdate-desc' => 'Holder de lokaliserede meddelelser så opdaterede som muligt',
);

/** German (Deutsch)
 * @author Kghbln
 * @author Purodha
 */
$messages['de'] = array(
	'localisationupdate-desc' => 'Ermöglicht es lokalisierte Texte und Nachrichten so aktuell wie möglich zu halten',
);

/** Lower Sorbian (dolnoserbski)
 * @author Michawiki
 */
$messages['dsb'] = array(
	'localisationupdate-desc' => 'Źaržy lokalizěrowane powěźeńki tak aktualne ako móžno',
);

/** Greek (Ελληνικά)
 * @author Omnipaedista
 */
$messages['el'] = array(
	'localisationupdate-desc' => 'Διατηρεί τις μεταφράσεις μηνυμάτων όσο πιο ενημερωμένες γίνεται',
);

/** Esperanto (Esperanto)
 * @author Yekrats
 */
$messages['eo'] = array(
	'localisationupdate-desc' => 'Ĝisdatigas la asimilitajn mesaĝojn tiom eble',
);

/** Spanish (español)
 * @author Crazymadlover
 */
$messages['es'] = array(
	'localisationupdate-desc' => 'Mantiene los mensajes localizados tan actualizados como sea posible',
);

/** Estonian (eesti)
 * @author Pikne
 */
$messages['et'] = array(
	'localisationupdate-desc' => 'Hoiab lokaliseeritud sõnumid nii ajakohased kui võimalik.',
);

/** Basque (euskara)
 * @author Kobazulo
 */
$messages['eu'] = array(
	'localisationupdate-desc' => 'Itzulitako mezuak ahalik eta eguneratuen mantentzen ditu',
);

/** Persian (فارسی)
 * @author ZxxZxxZ
 */
$messages['fa'] = array(
	'localisationupdate-desc' => 'پیغام‌های محلی‌سازی‌شده را تا جای ممکن به‌روز نگه می‌دارد',
);

/** Finnish (suomi)
 * @author Crt
 * @author Nike
 */
$messages['fi'] = array(
	'localisationupdate-desc' => 'Pitää ohjelmiston käännöksen ajantasaisena.',
);

/** French (français)
 * @author Crochet.david
 */
$messages['fr'] = array(
	'localisationupdate-desc' => 'Maintenir la traduction des messages à jour autant que possible',
);

/** Galician (galego)
 * @author Toliño
 */
$messages['gl'] = array(
	'localisationupdate-desc' => 'Mantén as mensaxes localizadas tan actualizadas como é posible',
);

/** Swiss German (Alemannisch)
 * @author Als-Holder
 */
$messages['gsw'] = array(
	'localisationupdate-desc' => 'Halt d Syschtemnochrichte so aktuälle wie megli',
);

/** Hebrew (עברית)
 * @author YaronSh
 */
$messages['he'] = array(
	'localisationupdate-desc' => 'שמירת ההודעות המתורגמות מעודכנות ככל הניתן',
);

/** Hiligaynon (Ilonggo)
 * @author Tagimata
 */
$messages['hil'] = array(
	'localisationupdate-desc' => 'Gatugo sang mga mensahe nga lokal para mapahibalo sang madali',
);

/** Croatian (hrvatski)
 * @author SpeedyGonsales
 */
$messages['hr'] = array(
	'localisationupdate-desc' => 'Dogradnja za osvježavanje lokalizacije poruka MediaWikija',
);

/** Upper Sorbian (hornjoserbsce)
 * @author Michawiki
 */
$messages['hsb'] = array(
	'localisationupdate-desc' => 'Dźerži lokalizowane zdźělenki tak aktualne kaž móžno',
);

/** Hungarian (magyar)
 * @author Glanthor Reviol
 */
$messages['hu'] = array(
	'localisationupdate-desc' => 'Frissíti a lefordított üzeneteket',
);

/** Interlingua (interlingua)
 * @author McDutchie
 */
$messages['ia'] = array(
	'localisationupdate-desc' => 'Mantene le messages localisate tanto actual como possibile',
);

/** Indonesian (Bahasa Indonesia)
 * @author Bennylin
 */
$messages['id'] = array(
	'localisationupdate-desc' => 'Mengusahakan agar pesan-pesan yang telah diterjemahkan tetap semutakhir mungkin',
);

/** Iloko (Ilokano)
 * @author Lam-ang
 */
$messages['ilo'] = array(
	'localisationupdate-desc' => 'Taginayonenna a mapabaro dagiti naipatarus a mensahe',
);

/** Italian (italiano)
 * @author Darth Kule
 */
$messages['it'] = array(
	'localisationupdate-desc' => 'Mantiene i messaggi localizzati quanto più aggiornati è possibile',
);

/** Japanese (日本語)
 * @author Fryed-peach
 * @author Shirayuki
 */
$messages['ja'] = array(
	'localisationupdate-desc' => 'メッセージの翻訳をできるだけ最新に保つ',
);

/** Khmer (ភាសាខ្មែរ)
 * @author វ័ណថារិទ្ធ
 */
$messages['km'] = array(
	'localisationupdate-desc' => 'រក្សា​សារ​ដែលបាន​ប្រែសម្រួល​ទាំងឡាយ អោយនៅ​ទាន់សម័យ​តាមដែលអាចធ្វើទៅបាន​',
);

/** Korean (한국어)
 * @author Kwj2772
 */
$messages['ko'] = array(
	'localisationupdate-desc' => '번역된 시스템 메시지를 가능한 한 최신으로 유지',
);

/** Colognian (Ripoarisch)
 * @author Purodha
 */
$messages['ksh'] = array(
	'localisationupdate-desc' => 'Texte un Nohreeschte vum Wiki esu joot wi müjjelich om neueste Shtand halde',
);

/** Luxembourgish (Lëtzebuergesch)
 * @author Robby
 */
$messages['lb'] = array(
	'localisationupdate-desc' => 'hält déi lokaliséiert Messagen esou aktuell wéi méiglech.',
);

/** Macedonian (македонски)
 * @author Bjankuloski06
 */
$messages['mk'] = array(
	'localisationupdate-desc' => 'Ги одржува локализираните пораки колку што е можно пообновени и повеќе во тек со настаните',
);

/** Malayalam (മലയാളം)
 * @author Praveenp
 */
$messages['ml'] = array(
	'localisationupdate-desc' => 'പ്രാദേശികഭാഷയിലാക്കിയ സന്ദേശങ്ങൾ കഴിയുന്നത്ര വേഗം ചേർക്കാൻ ഉപയോഗിക്കുന്നു',
);

/** Malay (Bahasa Melayu)
 * @author Anakmalaysia
 */
$messages['ms'] = array(
	'localisationupdate-desc' => 'Memastikan kekemaskinian mesej-mesej yang disetempatkan',
);

/** Norwegian Bokmål (norsk (bokmål)‎)
 * @author Nghtwlkr
 */
$messages['nb'] = array(
	'localisationupdate-desc' => 'Holder de lokaliserte meldingene så oppdaterte som mulig',
);

/** Dutch (Nederlands)
 * @author Siebrand
 */
$messages['nl'] = array(
	'localisationupdate-desc' => 'Houdt de gelokaliseerde berichten zo actueel mogelijk',
);

/** Norwegian Nynorsk (norsk (nynorsk)‎)
 * @author Gunnernett
 */
$messages['nn'] = array(
	'localisationupdate-desc' => 'Held dei lokaliserte meldingane så oppdaterte som mogleg',
);

/** Occitan (occitan)
 * @author Cedric31
 */
$messages['oc'] = array(
	'localisationupdate-desc' => 'Manténer la traduccion dels messatges a jorn autant que possible',
);

/** Polish (polski)
 * @author Sp5uhe
 */
$messages['pl'] = array(
	'localisationupdate-desc' => 'Uaktualnia lokalne komunikaty w miarę możliwości na bieżąco',
);

/** Piedmontese (Piemontèis)
 * @author Dragonòt
 */
$messages['pms'] = array(
	'localisationupdate-desc' => 'A manten i messagi localisà ël pì agiornà possìbil',
);

/** Portuguese (português)
 * @author Hamilton Abreu
 * @author Malafaya
 */
$messages['pt'] = array(
	'localisationupdate-desc' => 'Mantém as mensagens localizadas tão actualizadas quanto possível',
);

/** Brazilian Portuguese (português do Brasil)
 * @author Eduardo.mps
 */
$messages['pt-br'] = array(
	'localisationupdate-desc' => 'Mantém as mensagens localizadas tão atualizadas quanto possível',
);

/** Romanian (română)
 * @author KlaudiuMihaila
 */
$messages['ro'] = array(
	'localisationupdate-desc' => 'Menține mesajele localizate cât mai actualizate',
);

/** tarandíne (tarandíne)
 * @author Joetaras
 */
$messages['roa-tara'] = array(
	'localisationupdate-desc' => "Mandine le messagge localizzate 'u cchiù aggiornate possibbile",
);

/** Russian (русский)
 * @author Александр Сигачёв
 */
$messages['ru'] = array(
	'localisationupdate-desc' => 'Поддерживает актуальность локализованных сообщений, насколько это возможно',
);

/** Slovak (slovenčina)
 * @author Helix84
 */
$messages['sk'] = array(
	'localisationupdate-desc' => 'Udržiava lokalizované správy čo najaktuálnejšie',
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎)
 * @author Михајло Анђелковић
 */
$messages['sr-ec'] = array(
	'localisationupdate-desc' => 'Ажурира локализоване поруке колико је то могуће',
);

/** Serbian (Latin script) (srpski (latinica)‎)
 * @author Liangent
 */
$messages['sr-el'] = array(
	'localisationupdate-desc' => 'Ažurira lokalizovane poruke koliko je to moguće',
);

/** Sundanese (Basa Sunda)
 * @author Kandar
 */
$messages['su'] = array(
	'localisationupdate-desc' => 'Ngajaga sangkan talatah-talatah nu geus dialihbasakeun salawasnya mutahir',
);

/** Swedish (svenska)
 * @author Boivie
 */
$messages['sv'] = array(
	'localisationupdate-desc' => 'Håller de lokaliserade meddelandena så uppdaterade som möjligt',
);

/** Tamil (தமிழ்)
 * @author செல்வா
 */
$messages['ta'] = array(
	'localisationupdate-desc' => 'உட்சூழலுக்கான செய்திகளை கூடியமட்டிலும் இன்றையநிலையில் வைக்கப்பட்டுள்ளன',
);

/** Telugu (తెలుగు)
 * @author Veeven
 */
$messages['te'] = array(
	'localisationupdate-desc' => 'స్ధానికీకరించిన సందేశాలను సాధ్యమైనంత తాజాగా ఉంచుతుంది',
);

/** Tagalog (Tagalog)
 * @author AnakngAraw
 */
$messages['tl'] = array(
	'localisationupdate-desc' => 'Pinananatili ang mga mensaheng lokalisado bilang pinaka nasasapanahon',
);

/** Turkish (Türkçe)
 * @author Joseph
 */
$messages['tr'] = array(
	'localisationupdate-desc' => 'Yerelleştirilen mesajları mümkün olabildiğince güncel tutar',
);

/** Ukrainian (українська)
 * @author Prima klasy4na
 */
$messages['uk'] = array(
	'localisationupdate-desc' => 'Забезпечує оновлення локалізованих повідомлень у міру можливості',
);

/** Veps (vepsän kel’)
 * @author Игорь Бродский
 */
$messages['vep'] = array(
	'localisationupdate-desc' => 'Pidab lokaliziruidud tedotused veresin, ku voib',
);

/** Vietnamese (Tiếng Việt)
 * @author Vinhtantran
 */
$messages['vi'] = array(
	'localisationupdate-desc' => 'Giữ các thông điệp bản địa hóa được cập nhật nhất có thể',
);

/** Walloon (walon)
 * @author Srtxg
 */
$messages['wa'] = array(
	'localisationupdate-desc' => "Po wårder  les ratournaedjes di l' eterface li pus a djoû possibe",
);

/** Yiddish (ייִדיש)
 * @author פוילישער
 */
$messages['yi'] = array(
	'localisationupdate-desc' => 'האלטן די לאקאליזירטע מעלדונגען אקטועל ווי נאר מעגלעך',
);

/** Cantonese (粵語)
 * @author Tom Maaswinkel
 */
$messages['yue'] = array(
	'localisationupdate-desc' => '將本地化嘅信息保持最新',
);

/** Simplified Chinese (中文（简体）‎)
 * @author Tom Maaswinkel
 */
$messages['zh-hans'] = array(
	'localisationupdate-desc' => '将本地化的信息保持最新',
);

/** Traditional Chinese (中文（繁體）‎)
 * @author Mark85296341
 * @author Tom Maaswinkel
 */
$messages['zh-hant'] = array(
	'localisationupdate-desc' => '將本地化的資訊盡可能保持最新',
);

==> mediawiki-1.22.4.tar.gz: mediawiki-1.22.4/extensions/LocalisationUpdate/LocalisationUpdate.i18n.php <==
<?php
/**
 * Internationalisation file for LocalisationUpdate extension.
 *
 * @file
 * @ingroup Extensions
 */
 
$messages = array();

/** English
 * @author Tom Maaswinkel
 */
$messages['en'] = array(
	'localisationupdate-desc' => 'Keeps the localised messages as up to date as possible',
);

/** Message documentation (Message documentation)
 * @author Fryed-peach
 * @author Purodha
 * @author Shirayuki
 */
$messages['qqq'] = array(
	'localisationupdate-desc' => '{{desc|name=Localisation Update|url=http://www.mediawiki.org/wiki/Extension:LocalisationUpdate}}',
);

/** Afrikaans (Afrikaans)
 * @author Naudefj
 */
$messages['af'] = array(
	'localisationupdate-desc' => 'Hou die gelokaliseerde boodskappe so op datum as moontlik',
);

/** Arabic (العربية)
 * @author Meno25
 */
$messages['ar'] = array(
	'localisationupdate-desc' => 'يبقي الرسائل المترجمة محدثة كأفضل ما يكون',
);

/** Asturian (asturianu)
 * @author Xuacu
 */
$messages['ast'] = array(
	'localisationupdate-desc' => 'Caltién los mensaxes llocalizaos tan anovaos como se pueda',
);

/** Bashkir (башҡортса)
 * @author Assele
 */
$messages['ba'] = array(
	'localisationupdate-desc' => 'Локалләштерелгән хәбәрҙәрҙең мөмкин тиклем яңы булыуын тәьмин итә',
);

/** Bavarian (Boarisch)
 * @author Man77
 */
$messages['bar'] = array(
	'localisationupdate-desc' => "Lokalisiade Texte und Nåchrichtn so aktuell håidn wia's gråd gehd",
);

/** Belarusian (Taraškievica orthography) (беларуская (тарашкевіца)‎)
 * @author EugeneZelenko
 * @author Wizardist
 */
$messages['be-tarask'] = array(
	'localisationupdate-desc' => 'Сочыць за актуальнасьцю лякалізаваных паведамленьняў, наколькі гэта магчыма',
);

/** Bulgarian (български)
 * @author DCLXVI
 */
$messages['bg'] = array(
	'localisationupdate-desc' => 'Поддържа локализираните съобщения възможно най-актуални',
);

/** Bengali (বাংলা)
 * @author Bellayet
 */
$messages['bn'] = array(
	'localisationupdate-desc' => 'স্থানীয়করণকৃত বার্তাসমূহ যথাসম্ভব হালনাগাদ রাখে',
);

/** Breton (brezhoneg)
 * @author Fulup
 */
$messages['br'] = array(
	'localisationupdate-desc' => "Derc'hel da hizivaat ar c'hemennoù troet ken fonnus ha ma'z eus tu",
);

/** Bosnian (bosanski)
 * @author CERminator
 */
$messages['bs'] = array(
	'localisationupdate-desc' => 'Zadržavanje lokaliziranih poruka ažurnim koliko je god moguće',
);

/** Catalan (català)
 * @author Paucabot
 */
$messages['ca'] = array(
	'localisationupdate-desc' => 'Manté els missatges localitzats tan actualitzats com sigui possible',
);

/** Czech (česky)
 * @author Mormegil
 */
$messages['cs'] = array(
	'localisationupdate-desc' => 'Udržuje lokalizovaná hlášení co možná nejaktuálnější',
);

/** Welsh (Cymraeg)
 * @author Lloffiwr
 */
$messages['cy'] = array(
	'localisationupdate-desc' => "Yn diweddaru'r cyfieithiadau o negeseuon mor aml â phosib",
);

/** Danish (dansk)
 * @author Peter Alberti
 */
$messages['da'] = array(
	'localisationupdate-desc' => 'Holder de lokaliserede meddelelser så opdaterede som muligt',
);

/** German (Deutsch)
 * @author Kghbln
 * @author Purodha
 */
$messages['de'] = array(
	'localisationupdate-desc' => 'Ermöglicht es lokalisierte Texte und Nachrichten so aktuell wie möglich zu halten',
);

/** Lower Sorbian (dolnoserbski)
 * @author Michawiki
 */
$messages['dsb'] = array(
	'localisationupdate-desc' => 'Źaržy lokalizěrowane powěźeńki tak aktualne ako móžno',
);

/** Greek (Ελληνικά)
 * @author Omnipaedista
 */
$messages['el'] = array(
	'localisationupdate-desc' => 'Διατηρεί τις μεταφράσεις μηνυμάτων όσο πιο ενημερωμένες γίνεται',
);

/** Esperanto (Esperanto)
 * @author Yekrats
 */
$messages['eo'] = array(
	'localisationupdate-desc' => 'Ĝisdatigas la asimilitajn mesaĝojn tiom eble',
);

/** Spanish (español)
 * @author Crazymadlover
 */
$messages['es'] = array(
	'localisationupdate-desc' => 'Mantiene los mensajes localizados tan actualizados como sea posible',
);

/** Estonian (eesti)
 * @author Pikne
 */
$messages['et'] = array(
	'localisationupdate-desc' => 'Hoiab lokaliseeritud sõnumid nii ajakohased kui võimalik.',
);

/** Basque (euskara)
 * @author Kobazulo
 */
$messages['eu'] = array(
	'localisationupdate-desc' => 'Itzulitako mezuak ahalik eta eguneratuen mantentzen ditu',
);

/** Persian (فارسی)
 * @author ZxxZxxZ
 */
$messages['fa'] = array(
	'localisationupdate-desc' => 'پیغام‌های محلی‌سازی‌شده را تا جای ممکن به‌روز نگه می‌دارد',
);

/** Finnish (suomi)
 * @author Crt
 * @author Nike
 */
$messages['fi'] = array(
	'localisationupdate-desc' => 'Pitää ohjelmiston käännöksen ajantasaisena.',
);

/** French (français)
 * @author Crochet.david
 */
$messages['fr'] = array(
	'localisationupdate-desc' => 'Maintenir la traduction des messages à jour autant que possible',
);

/** Galician (galego)
 * @author Toliño
 */
$messages['gl'] = array(
	'localisationupdate-desc' => 'Mantén as mensaxes localizadas tan actualizadas como é posible',
);

/** Swiss German (Alemannisch)
 * @author Als-Holder
 */
$messages['gsw'] = array(
	'localisationupdate-desc' => 'Halt d Syschtemnochrichte so aktuälle wie megli',
);

/** Hebrew (עברית)
 * @author YaronSh
 */
$messages['he'] = array(
	'localisationupdate-desc' => 'שמירת ההודעות המתורגמות מעודכנות ככל הניתן',
);

/** Hiligaynon (Ilonggo)
 * @author Tagimata
 */
$messages['hil'] = array(
	'localisationupdate-desc' => 'Gatugo sang mga mensahe nga lokal para mapahibalo sang madali',
);

/** Croatian (hrvatski)
 * @author SpeedyGonsales
 */
$messages['hr'] = array(
	'localisationupdate-desc' => 'Dogradnja za osvježavanje lokalizacije poruka MediaWikija',
);

/** Upper Sorbian (hornjoserbsce)
 * @author Michawiki
 */
$messages['hsb'] = array(
	'localisationupdate-desc' => 'Dźerži lokalizowane zdźělenki tak aktualne kaž móžno',
);

/** Hungarian (magyar)
 * @author Glanthor Reviol
 */
$messages['hu'] = array(
	'localisationupdate-desc' => 'Frissíti a lefordított üzeneteket',
);

/** Interlingua (interlingua)
 * @author McDutchie
 */
$messages['ia'] = array(
	'localisationupdate-desc' => 'Mantene le messages localisate tanto actual como possibile',
);

/** Indonesian (Bahasa Indonesia)
 * @author Bennylin
 */
$messages['id'] = array(
	'localisationupdate-desc' => 'Mengusahakan agar pesan-pesan yang telah diterjemahkan tetap semutakhir mungkin',
);

/** Iloko (Ilokano)
 * @author Lam-ang
 */
$messages['ilo'] = array(
	'localisationupdate-desc' => 'Taginayonenna a mapabaro dagiti naipatarus a mensahe',
);

/** Italian (italiano)
 * @author Darth Kule
 */
$messages['it'] = array(
	'localisationupdate-desc' => 'Mantiene i messaggi localizzati quanto più aggiornati è possibile',
);

/** Japanese (日本語)
 * @author Fryed-peach
 * @author Shirayuki
 */
$messages['ja'] = array(
	'localisationupdate-desc' => 'メッセージの翻訳をできるだけ最新に保つ',
);

/** Khmer (ភាសាខ្មែរ)
 * @author វ័ណថារិទ្ធ
 */
$messages['km'] = array(
	'localisationupdate-desc' => 'រក្សា​សារ​ដែលបាន​ប្រែសម្រួល​ទាំងឡាយ អោយនៅ​ទាន់សម័យ​តាមដែលអាចធ្វើទៅបាន​',
);

/** Korean (한국어)
 * @author Kwj2772
 * @author 아라
 */
$messages['ko'] = array(
	'localisationupdate-desc' => '번역된 메시지를 가능한 한 최신으로 유지합니다',
);

/** Colognian (Ripoarisch)
 * @author Purodha
 */
$messages['ksh'] = array(
	'localisationupdate-desc' => 'Texte un Nohreeschte vum Wiki esu joot wi müjjelich om neueste Shtand halde',
);

/** Luxembourgish (Lëtzebuergesch)
 * @author Robby
 */
$messages['lb'] = array(
	'localisationupdate-desc' => 'hält déi lokaliséiert Messagen esou aktuell wéi méiglech.',
);

/** Macedonian (македонски)
 * @author Bjankuloski06
 */
$messages['mk'] = array(
	'localisationupdate-desc' => 'Ги одржува локализираните пораки колку што е можно пообновени и повеќе во тек со настаните',
);

/** Malayalam (മലയാളം)
 * @author Praveenp
 */
$messages['ml'] = array(
	'localisationupdate-desc' => 'പ്രാദേശികഭാഷയിലാക്കിയ സന്ദേശങ്ങൾ കഴിയുന്നത്ര വേഗം ചേർക്കാൻ ഉപയോഗിക്കുന്നു',
);

/** Malay (Bahasa Melayu)
 * @author Anakmalaysia
 */
$messages['ms'] = array(
	'localisationupdate-desc' => 'Memastikan kekemaskinian mesej-mesej yang disetempatkan',
);

/** Norwegian Bokmål (norsk bokmål)
 * @author Nghtwlkr
 */
$messages['nb'] = array(
	'localisationupdate-desc' => 'Holder de lokaliserte meldingene så oppdaterte som mulig',
);

/** Dutch (Nederlands)
 * @author Siebrand
 */
$messages['nl'] = array(
	'localisationupdate-desc' => 'Houdt de gelokaliseerde berichten zo actueel mogelijk',
);

/** Norwegian Nynorsk (norsk nynorsk)
 * @author Gunnernett
 */
$messages['nn'] = array(
	'localisationupdate-desc' => 'Held dei lokaliserte meldingane så oppdaterte som mogleg',
);

/** Occitan (occitan)
 * @author Cedric31
 */
$messages['oc'] = array(
	'localisationupdate-desc' => 'Manténer la traduccion dels messatges a jorn autant que possible',
);

/** Polish (polski)
 * @author Sp5uhe
 */
$messages['pl'] = array(
	'localisationupdate-desc' => 'Uaktualnia lokalne komunikaty w miarę możliwości na bieżąco',
);

/** Piedmontese (Piemontèis)
 * @author Dragonòt
 */
$messages['pms'] = array(
	'localisationupdate-desc' => 'A manten i messagi localisà ël pì agiornà possìbil',
);

/** Portuguese (português)
 * @author Hamilton Abreu
 * @author Luckas
 * @author Malafaya
 */
$messages['pt'] = array(
	'localisationupdate-desc' => 'Mantém as mensagens localizadas tão atualizadas quanto possível',
);

/** Brazilian Portuguese (português do Brasil)
 * @author Eduardo.mps
 */
$messages['pt-br'] = array(
	'localisationupdate-desc' => 'Mantém as mensagens localizadas tão atualizadas quanto possível',
);

/** Romanian (română)
 * @author KlaudiuMihaila
 */
$messages['ro'] = array(
	'localisationupdate-desc' => 'Menține mesajele localizate cât mai actualizate',
);

/** tarandíne (tarandíne)
 * @author Joetaras
 */
$messages['roa-tara'] = array(
	'localisationupdate-desc' => "Mandine le messagge localizzate 'u cchiù aggiornate possibbile",
);

/** Russian (русский)
 * @author Александр Сигачёв
 */
$messages['ru'] = array(
	'localisationupdate-desc' => 'Поддерживает актуальность локализованных сообщений, насколько это возможно',
);

/** Slovak (slovenčina)
 * @author Helix84
 */
$messages['sk'] = array(
	'localisationupdate-desc' => 'Udržiava lokalizované správy čo najaktuálnejšie',
);

/** Serbian (Cyrillic script) (српски (ћирилица)‎)
 * @author Михајло Анђелковић
 */
$messages['sr-ec'] = array(
	'localisationupdate-desc' => 'Ажурира локализоване поруке колико је то могуће',
);

/** Serbian (Latin script) (srpski (latinica)‎)
 * @author Liangent
 */
$messages['sr-el'] = array(
	'localisationupdate-desc' => 'Ažurira lokalizovane poruke koliko je to moguće',
);

/** Sundanese (Basa Sunda)
 * @author Kandar
 */
$messages['su'] = array(
	'localisationupdate-desc' => 'Ngajaga sangkan talatah-talatah nu geus dialihbasakeun salawasnya mutahir',
);

/** Swedish (svenska)
 * @author Boivie
 */
$messages['sv'] = array(
	'localisationupdate-desc' => 'Håller de lokaliserade meddelandena så uppdaterade som möjligt',
);

/** Tamil (தமிழ்)
 * @author செல்வா
 */
$messages['ta'] = array(
	'localisationupdate-desc' => 'உட்சூழலுக்கான செய்திகளை கூடியமட்டிலும் இன்றையநிலையில் வைக்கப்பட்டுள்ளன',
);

/** Telugu (తెలుగు)
 * @author Veeven
 */
$messages['te'] = array(
	'localisationupdate-desc' => 'స్ధానికీకరించిన సందేశాలను సాధ్యమైనంత తాజాగా ఉంచుతుంది',
);

/** Tagalog (Tagalog)
 * @author AnakngAraw
 */
$messages['tl'] = array(
	'localisationupdate-desc' => 'Pinananatili ang mga mensaheng lokalisado bilang pinaka nasasapanahon',
);

/** Turkish (Türkçe)
 * @author Joseph
 */
$messages['tr'] = array(
	'localisationupdate-desc' => 'Yerelleştirilen mesajları mümkün olabildiğince güncel tutar',
);

/** Ukrainian (українська)
 * @author Prima klasy4na
 */
$messages['uk'] = array(
	'localisationupdate-desc' => 'Забезпечує оновлення локалізованих повідомлень у міру можливості',
);

/** Veps (vepsän kel’)
 * @author Игорь Бродский
 */
$messages['vep'] = array(
	'localisationupdate-desc' => 'Pidab lokaliziruidud tedotused veresin, ku voib',
);

/** Vietnamese (Tiếng Việt)
 * @author Vinhtantran
 */
$messages['vi'] = array(
	'localisationupdate-desc' => 'Giữ các thông điệp bản địa hóa được cập nhật nhất có thể',
);

/** Walloon (walon)
 * @author Srtxg
 */
$messages['wa'] = array(
	'localisationupdate-desc' => "Po wårder  les ratournaedjes di l' eterface li pus a djoû possibe",
);

/** Yiddish (ייִדיש)
 * @author פוילישער
 */
$messages['yi'] = array(
	'localisationupdate-desc' => 'האלטן די לאקאליזירטע מעלדונגען אקטועל ווי נאר מעגלעך',
);

/** Cantonese (粵語)
 * @author Tom Maaswinkel
 */
$messages['yue'] = array(
	'localisationupdate-desc' => '將本地化嘅信息保持最新',
);

/** Simplified Chinese (中文（简体）‎)
 * @author Tom Maaswinkel
 */
$messages['zh-hans'] = array(
	'localisationupdate-desc' => '将本地化的信息保持最新',
);

/** Traditional Chinese (中文（繁體）‎)
 * @author Mark85296341
 * @author Tom Maaswinkel
 */
$messages['zh-hant'] = array(
	'localisationupdate-desc' => '將本地化的資訊盡可能保持最新',
);
